@@ -135,14 +135,14 @@ automatic update of widget attributes
 ^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
 
 Dependencies have to be executed/read_from, so e.g. the icon attribute will not be updated if
-app.ae_state_light_theme gets changed::
+app.app_state_light_theme gets changed::
 
-    icon << main_app.cached_icon('font_size') or app.ae_state_light_theme
+    icon << main_app.cached_icon('font_size') or app.app_state_light_theme
 
 In contrary the icon will be updated by the following two statements::
 
-    icon << main_app.cached_icon('font_size') if app.ae_state_light_theme else main_app.cached_icon('font_size')
-    icon << app.ae_state_light_theme == None or main_app.cached_icon('font_size')
+    icon << main_app.cached_icon('font_size') if app.app_state_light_theme else main_app.cached_icon('font_size')
+    icon << app.app_state_light_theme == None or main_app.cached_icon('font_size')
 
 KeyEvent implementation based on this SO answer posted by the enamlx author frmdstryr/Jairus Martin:
 https://stackoverflow.com/questions/20380940/how-to-get-key-events-when-using-enaml. Alternative
@@ -167,7 +167,7 @@ from ae.i18n import get_f_string
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action   # type: ignore
 
 
-__version__ = '0.1.19'
+__version__ = '0.1.20'
 
 
 NODE_FILE_PREFIX = 'node_'  #: file name prefix for node imports/exports
